@@ -14,7 +14,7 @@ from copy import deepcopy
 
 from magnelPy import statFunc
 from magnelPy.admin import df_writeToExcel
-from magnelPy.stochVar import createStochVar
+from magnelPy.stochVar import createStochVar,fx
 
 
 # import sys
@@ -272,10 +272,34 @@ def MDRMG(varDict,L=5,outdir='TMP'):
 	# text_file.write("Stochastic variable reference file:\n%s\n\nsheet:\n%s" %(filename,sheet)) 
 	# text_file.close()
 
+def ImportanceSampling(n_sim,ParameterList,ParameterList_IS):
+    ### importance sampling functionality; LS independent (does not itself evaluate the LS)
+    ### note: ParameterList and ParameterDict_IS need to be in the same order
+    X=pd.DataFrame(); k=np.ones(n_sim) # initialization output and k-factor
+    for i,var in enumerate(ParameterList_IS):
+        X[var['name']]=MCS_var(var,n_sim) # sampling according to ParameterList_IS
+        kvar=IS_factor(X[var['name']],ParameterList[i],var)
+        k*=kvar
+    X['IS_factor']=k
+    return X
+
+def MCS(n_sim,ParameterList):
+    ### crude monte carlo functionality; LS independent (does not itself evaluate the LS)
+    X=pd.DataFrame(); k=np.ones(n_sim) # initialization output and k-factor
+    for i,var in enumerate(ParameterList):
+        X[var['name']]=MCS_var(var,n_sim) # sampling according to ParameterList
+    return X	
+
+
 ##################
 ## AUX FUNCTION ##
 ##################
 
+def IS_factor(x,varDictX,varDictXis):
+	# likelihood ratio within importance sampling
+	return np.exp(np.log(fx(varDictX,x))-np.log(fx(varDictXis,x)))
+
+
 def ParameterRealization_r(varDict,rArray):
 	#------------------------------------------------------------------------------------------------------------
 	# Realizations stochastic variable
